-- ------------------------------------------------------------------------------
-- File: 	boldLineTriggerExample.sql
-- Author:	Chadd Williams
-- Date: 	11/17/2017
-- Class:	CS445
-- Purpose:	Demonstrate Trigger
-- ------------------------------------------------------------------------------

drop table if exists Wrote;
drop table if exists Authors;
drop table if exists Books;

CREATE TABLE Authors (
	AuthorID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	FName VARCHAR(20),
	LName VARCHAR(20)
) Engine = InnoDB;

CREATE TABLE Books (
	BookID INT NOT NULL AUTO_INCREMENT PRIMARY KEY,
	Title CHAR(200)
) Engine = InnoDB;

CREATE TABLE Wrote (
	BookID INT NOT NULL,
	AuthorID INT NOT NULL,
	
	CONSTRAINT Wrote_BookIDAuthorID_PK PRIMARY KEY 
		(BookID, AuthorID),

	CONSTRAINT Wrote_BookID_FK FOREIGN KEY (BookID) 
		REFERENCES Books(BookID) ON DELETE CASCADE,

	CONSTRAINT Wrote_AuthorID_FK FOREIGN KEY (AuthorID) 
		REFERENCES Authors(AuthorID) ON DELETE CASCADE
		
) Engine = InnoDB;

INSERT INTO Authors (FName, LName) VALUES ('Raghu', 'Ramakrishnan');

INSERT INTO Books (Title) VALUES ('Database Management Systems');

INSERT INTO Wrote (BookID, AuthorID) VALUES (1, 1);

DELIMITER //
Create Trigger BoldLine BEFORE DELETE ON  Wrote
For each row
Begin
  	declare homeRowCount INTEGER;
	declare rowCount INTEGER;

	SELECT COUNT(*) FROM Books WHERE
		BookID=OLD.BookID into homeRowCount;

	SELECT Count(*) from Wrote Where 		
		Wrote.BookID=OLD.BookID into rowCount;
		
	If homeRowCount > 0 and rowCount = 1 THEN
		SIGNAL SQLSTATE '45000'
			SET MESSAGE_TEXT = 'Bold Line';
	END IF;
END; // -- check with on delete cascade
DELIMITER ;

-- show triggers;

-- delete from Wrote where BookID=1;

-- delete from Books where BookID=1;

-- select * from Wrote;

-- select * from Books;